% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Calibration.R
\name{Calibration}
\alias{Calibration}
\title{Calibration based on an ensemble inflation (Doblas-Reyes et al. 2005)}
\usage{
Calibration(data)
}
\arguments{
\item{data}{a list of s2dverification objects (lists) as output by the \code{Load} function from the s2dverification package, one for each variable.}

\value{
\code{$calibrated} {An array with the calibrated forecasts with same dimensions that data$mod}
}
\description{
This function applies a variance inflation technique described in Doblas-Reyes et al. (2005) in leave-one-out cross-validation. The calibrated forecasts have an equivalent variance to that of the reference dataset, but at the same time preserve reliability. 
}
\examples{
# Creation of sample s2dverification objects. These are not complete
# s2dverification objects though. The Load function returns complete objects.
# Example
mod1 <- 1 : (1 * 3 * 4 * 5 * 6 * 7)
dim(mod1) <- c(dataset = 1, member = 3, sdate = 4, ftime = 5, lat = 6, lon = 7)
obs1 <- 1 : (1 * 1 * 4 * 5 * 6 * 7)
dim(obs1) <- c(dataset = 1, member = 1, sdate = 4, ftime = 5, lat = 6, lon = 7)
lon <- seq(0, 30, 5)
lat <- seq(0, 25, 5)
data1 <- list(mod = mod1, obs = obs1, lat = lat, lon = lon)
a <- Calibration(data1)
str(a)
dim(mod1) <-
  c(
    dataset = 1,
    member = 3,
    sdate = 4,
    ftime = 5,
    lat = 6,
    lon = 7
  )
dim(obs1) <-
  c(
    dataset = 1,
    member = 1,
    sdate = 4,
    ftime = 5,
    lat = 6,
    lon = 7
  )
lon <- seq(0, 30, 5)
lat <- seq(0, 25, 5)

data1 <- list(
  mod = mod1,
  obs = obs1,
  lat = lat,
  lon = lon
)
a1 <- Calibration(data1)

mod2 <- mod1
mod2[1, 2, 1, 1, 1, 1] <- NA
data2 <- list(
  mod = mod2,
  obs = obs1,
  lat = lat,
  lon = lon
)
a2 <- Calibration(data2)

obs2 <- obs1
obs2[1, 1, 2, 1, 1, 1] <- NA
data3 <- list(
  mod = mod1,
  obs = obs2,
  lat = lat,
  lon = lon
)
a3 <- Calibration(data3)

data4 <- list(
  mod = mod2,
  obs = obs2,
  lat = lat,
  lon = lon
)
a4 <- Calibration(data4)

lat2 <- lat
lat2[3] <- NA
data5 <- list(
  mod = mod1,
  obs = obs1,
  lat = lat2,
  lon = lon
)
a5 <- Calibration(data5)

lon2 <- lon
lon2[5] <- NA
data6 <- list(
  mod = mod1,
  obs = obs1,
  lat = lat,
  lon = lon2
)
a6 <- Calibration(data6)

data7 <- list(
  mod = mod1,
  obs = obs1,
  lat = lat2,
  lon = lon2
)
a7 <- Calibration(data7)

data8 <- list(
  mod = mod1,
  obs = obs2,
  lat = lat2,
  lon = lon2
)
a8 <- Calibration(data8)

data9 <- list(
  mod = mod2,
  obs = obs1,
  lat = lat2,
  lon = lon2
)
a9 <- Calibration(data9)

data10 <- list(
  mod = mod2,
  obs = obs2,
  lat = lat2,
  lon = lon2
)
a10 <- Calibration(data10)
}
\references{
Doblas-Reyes, F. J., Hagedorn, R., & Palmer, T. N. (2005). The rationale behind the success of multi-model ensembles in seasonal forecasting—II. Calibration and combination. Tellus A: Dynamic Meteorology and Oceanography, 57(3), 234-252.

Torralba, V., Doblas-Reyes, F. J., MacLeod, D., Christel, I., & Davis, M. (2017). Seasonal climate prediction: A new source of information for the management of wind energy resources. Journal of Applied Meteorology and Climatology, 56(5), 1231-1247.

}
\author{
Verónica Torralba, \email{veronica.torralba@bsc.es}
}


